@@ -35,8 +35,8 @@ EVENT_STRIKE = "evt_strike"
 UNIT_DECIBELS = units.dB
 UNIT_DEGREES = units.deg
 UNIT_DEGREES_CELSIUS = units.degC
-UNIT_IRRADIATION = units.W / units.m ** 2
-UNIT_KILOGRAMS_PER_CUBIC_METER = units.kg / units.m ** 3
+UNIT_IRRADIATION = units.W / units.m**2
+UNIT_KILOGRAMS_PER_CUBIC_METER = units.kg / units.m**3
 UNIT_KILOMETERS = units.km
 UNIT_LUX = units.lx
 UNIT_METERS = units.m
@@ -44,7 +44,7 @@ UNIT_METERS_PER_SECOND = units.m / units.sec
 UNIT_MILLIBARS = units.mbar
 UNIT_MILLIMETERS = units.mm
 UNIT_MILLIMETERS_PER_MINUTE = units.mm / units.min
-UNIT_MILLIMETERS_PER_HOUR = units.mm / units.hr
+UNIT_MILLIMETERS_PER_HOUR = units.mm / units.h
 UNIT_MINUTES = units.min
 UNIT_PERCENT = units.percent
 UNIT_SECONDS = units.sec
