@@ -5,6 +5,7 @@ from datetime import datetime, timezone
 from typing import Any, TypeVar
 
 from pint import Quantity
+from pint.unit import Unit
 
 DIRECTIONS = [
     "N",
@@ -55,3 +56,12 @@ def truebool(val: Any | None) -> bool:
 def utc_timestamp_from_epoch(epoch: int | None) -> datetime | None:
     """Return the UTC timestamp from an epoch value."""
     return None if epoch is None else datetime.fromtimestamp(epoch, UTC)
+
+
+def value_as_unit(value: T | None, unit: Unit = None) -> T | Quantity[T] | None:
+    """Return value as specified unit or sensor fault if value is none."""
+    if value is None:
+        return None
+    if unit is None:
+        return value
+    return value * unit
